#
#   Carta di Smith.
#   Copyright (C) 2014 2015  Alessandro Accattini
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#
##############################################################################
#
#
#

set terminal png size 640,640 x000000 xffffff


# Definizioni globali
tmin=0.0
tmax=20.0


# Funzioni
Z(r,x)=r*{1,0}+x*{0,1}
Y(z)=1/z
Gamma(z)=(z-1)/(z+1)
Range(t,sta,sto)=t*(sto-sta)/(tmax-tmin)+sta-tmin*(sto-sta)/(tmax-tmin)

Zline(Z,Z0,beta,L)=Z0*(Z+{0,1}*Z0*tan(beta*L))/(Z0+{0,1}*Z*tan(beta*L))
Beta(lam)=2.0*pi/lam

w(f)=2*pi*f
dB(v)=20*log10(v)
Zl(w,L)=w*L*{0,1}
Zc(w,C)=1/({0,1}*w*C)
Par(Z1,Z2)=Z1*Z2/(Z1+Z2)


# Linee di riferimento della carta di smith
set macros
RefR00p="real(Gamma(Z( 0.0, t))),imag(Gamma(Z( 0.0, t))) lt 5 lw 2"
RefR00n="real(Gamma(Z( 0.0,-t))),imag(Gamma(Z( 0.0,-t))) lt 5 lw 2"
RefR05p="real(Gamma(Z( 0.5, t))),imag(Gamma(Z( 0.5, t))) lt 3 lw 1"
RefR05n="real(Gamma(Z( 0.5,-t))),imag(Gamma(Z( 0.5,-t))) lt 3 lw 1"
RefR10p="real(Gamma(Z( 1.0, t))),imag(Gamma(Z( 1.0, t))) lt 3 lw 1"
RefR10n="real(Gamma(Z( 1.0,-t))),imag(Gamma(Z( 1.0,-t))) lt 3 lw 1"
RefR20p="real(Gamma(Z( 2.0, t))),imag(Gamma(Z( 2.0, t))) lt 3 lw 1"
RefR20n="real(Gamma(Z( 2.0,-t))),imag(Gamma(Z( 2.0,-t))) lt 3 lw 1"
RefI00 ="real(Gamma(Z(t, 0.0))),imag(Gamma(Z(t, 0.0))) lt 3 lw 1" 
RefI05p="real(Gamma(Z(t, 0.5))),imag(Gamma(Z(t, 0.5))) lt 3 lw 1"
RefI05n="real(Gamma(Z(t,-0.5))),imag(Gamma(Z(t,-0.5))) lt 3 lw 1"
RefI10p="real(Gamma(Z(t, 1.0))),imag(Gamma(Z(t, 1.0))) lt 3 lw 1"
RefI10n="real(Gamma(Z(t,-1.0))),imag(Gamma(Z(t,-1.0))) lt 3 lw 1"
RefI20p="real(Gamma(Z(t, 2.0))),imag(Gamma(Z(t, 2.0))) lt 3 lw 1"
RefI20n="real(Gamma(Z(t,-2.0))),imag(Gamma(Z(t,-2.0))) lt 3 lw 1"
RefY10p="real(Gamma(Y(Z( 1.0, t)))),imag(Gamma(Y(Z( 1.0, t)))) lt 4 lw 1"
RefY10n="real(Gamma(Y(Z( 1.0,-t)))),imag(Gamma(Y(Z( 1.0,-t)))) lt 4 lw 1"
CentRad=real(Gamma(2.0))
Center= "cos(Range(t,0,2*pi))*CentRad,sin(Range(t,0,2*pi))*CentRad lt 4 lw 1"

# punti di riferimento
StdStyle="front point ps 3 offset 0.4,0.4"
Pnt1="real(Gamma(Z(1, 0.0))),imag(Gamma(Z(1, 0.0)))"
Pnt2="real(Gamma(Z(1, 0.5))),imag(Gamma(Z(1, 0.5)))"
Pnt3="real(Gamma(Z(1,-0.5))),imag(Gamma(Z(1,-0.5)))"
Pnt4="real(Gamma(Z(0.5, 0))),imag(Gamma(Z(0.5, 0)))"
Pnt5="real(Gamma(Z(2, 0.0))),imag(Gamma(Z(2, 0.0)))"
Pnt6="real(Gamma(Z(1, 1.0))),imag(Gamma(Z(1, 1.0)))"
Pnt7="real(Gamma(Z(1,-1.0))),imag(Gamma(Z(1,-1.0)))"
Pnt8="real(Gamma(Z(1, 2.0))),imag(Gamma(Z(1, 2.0)))"
Pnt9="real(Gamma(Z(1,-2.0))),imag(Gamma(Z(1,-2.0)))"




set grid x y

#set key on
#set key title "lines"
#set key Left reverse samplen 1 box lw 1
#set key width 1 height 1
#set key left
set key off

set samples 400
set parametric

set trange[tmin:tmax]
set xrange[-1.1:1.1]
set yrange[-1.1:1.1]

set xtics 0.20
set ytics 0.20

set title "Carta di Smith"


set label 1 "1+j0"   at @Pnt1 @StdStyle
set label 2 "1+j0.5" at @Pnt2 @StdStyle
set label 3 "1-j0.5" at @Pnt3 @StdStyle
set label 4 "0.5+j0" at @Pnt4 @StdStyle
set label 5 "2+j0"   at @Pnt5 @StdStyle
set label 6 "1+j1"   at @Pnt6 @StdStyle
set label 7 "1-j1"   at @Pnt7 @StdStyle
set label 8 "1+j2"   at @Pnt8 @StdStyle
set label 9 "1-j2"   at @Pnt9 @StdStyle


plot	@RefR00p,@RefR00n,@RefR05p,@RefR05n, \
	@RefR10p,@RefR10n,@RefR20p,@RefR20n, \
	@RefI00,@RefI05p,@RefI05n,@RefI10p,@RefI10n,@RefI20p,@RefI20n, \
	@RefY10p,@RefY10n,@Center


