#
#   Adattamento di una antenna loop tramite carta di Smith.
#   Copyright (C) 2014 2015  Alessandro Accattini
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#
##############################################################################
#
#
#

set terminal png size 640,640 x000000 xffffff


# Definizioni globali
tmin=0.0
tmax=20.0


# Funzioni
Z(r,x)=r*{1,0}+x*{0,1}
Y(z)=1/z
Gamma(z)=(z-1)/(z+1)
Range(t,sta,sto)=t*(sto-sta)/(tmax-tmin)+sta-tmin*(sto-sta)/(tmax-tmin)

Zline(Z,Z0,beta,L)=Z0*(Z+{0,1}*Z0*tan(beta*L))/(Z0+{0,1}*Z*tan(beta*L))
Beta(lam)=2.0*pi/lam

w(f)=2*pi*f
dB(v)=20*log10(v)
Zl(w,L)=w*L*{0,1}
Zc(w,C)=1/({0,1}*w*C)
Par(Z1,Z2)=Z1*Z2/(Z1+Z2)


# Linee di riferimento della carta di smith
set macros
RefR00p="real(Gamma(Z( 0.0, t))),imag(Gamma(Z( 0.0, t))) lt 5 lw 2"
RefR00n="real(Gamma(Z( 0.0,-t))),imag(Gamma(Z( 0.0,-t))) lt 5 lw 2"
RefR05p="real(Gamma(Z( 0.5, t))),imag(Gamma(Z( 0.5, t))) lt 3 lw 1"
RefR05n="real(Gamma(Z( 0.5,-t))),imag(Gamma(Z( 0.5,-t))) lt 3 lw 1"
RefR10p="real(Gamma(Z( 1.0, t))),imag(Gamma(Z( 1.0, t))) lt 3 lw 1"
RefR10n="real(Gamma(Z( 1.0,-t))),imag(Gamma(Z( 1.0,-t))) lt 3 lw 1"
RefR20p="real(Gamma(Z( 2.0, t))),imag(Gamma(Z( 2.0, t))) lt 3 lw 1"
RefR20n="real(Gamma(Z( 2.0,-t))),imag(Gamma(Z( 2.0,-t))) lt 3 lw 1"
RefI00 ="real(Gamma(Z(t, 0.0))),imag(Gamma(Z(t, 0.0))) lt 3 lw 1" 
RefI05p="real(Gamma(Z(t, 0.5))),imag(Gamma(Z(t, 0.5))) lt 3 lw 1"
RefI05n="real(Gamma(Z(t,-0.5))),imag(Gamma(Z(t,-0.5))) lt 3 lw 1"
RefI10p="real(Gamma(Z(t, 1.0))),imag(Gamma(Z(t, 1.0))) lt 3 lw 1"
RefI10n="real(Gamma(Z(t,-1.0))),imag(Gamma(Z(t,-1.0))) lt 3 lw 1"
RefI20p="real(Gamma(Z(t, 2.0))),imag(Gamma(Z(t, 2.0))) lt 3 lw 1"
RefI20n="real(Gamma(Z(t,-2.0))),imag(Gamma(Z(t,-2.0))) lt 3 lw 1"
RefY10p="real(Gamma(Y(Z( 1.0, t)))),imag(Gamma(Y(Z( 1.0, t)))) lt 4 lw 1"
RefY10n="real(Gamma(Y(Z( 1.0,-t)))),imag(Gamma(Y(Z( 1.0,-t)))) lt 4 lw 1"
CentRad=real(Gamma(2.0))
Center= "cos(Range(t,0,2*pi))*CentRad,sin(Range(t,0,2*pi))*CentRad lt 4 lw 1"

# punti di riferimento
StdStyle="front point ps 3 offset 0.4,0.4"

Pnt_Zp ="real(Gamma(Zp/Zn)),imag(Gamma(Zp/Zn))"
Pnt_Zp1="real(Gamma(Zp1(Cpf)/Zn)),imag(Gamma(Zp1(Cpf)/Zn))"
Pnt_Zp2="real(Gamma(Zp2(Cpf,Csf)/Zn)),imag(Gamma(Zp2(Cpf,Csf)/Zn))"
Pnt_Zp3="real(Gamma(Zp3(Cpf,Csf,Cef)/Zn)),imag(Gamma(Zp3(Cpf,Csf,Cef)/Zn))"
Pnt_Zp4="real(Gamma(Zp4(Cpf,Csf,Cef,Lef)/Zn)),imag(Gamma(Zp4(Cpf,Csf,Cef,Lef)/Zn))"




# Frequenza di lavoro
f1=13.56e6

# caratteristiche elettriche dell'antenna
Ls=310e-9 * 1.00
Rs=0.150

# caratteristiche elettriche dell'ingresso del transceiver
Cin=22e-12
Rin=660.0

# impedenza caratteristica di riferimento (Rout del transceiver)
Zn=27.0



# determina l'impedenza del carico
Zp=Par(Par(( Zl(w(f1),Ls) + Rs ),( Zc(w(f1),Cin) + Rin )), 1000.0)

# al carico viene posto in parallelo un condensatore Cp
Cpf=390e-12
Zp1(Cp)=Par(Zp,Zc(w(f1),Cp))

# al risultato viene posto in serie un condensatore Cs
Csf=120e-12/2.0
Zp2(Cp,Cs)=Zp1(Cp) + Zc(w(f1),Cs)

# al risultato viene posto in parallelo un condensatore Ce
Cef=200e-12
Zp3(Cp,Cs,Ce)=Par(Zp2(Cp,Cs),Zc(w(f1),Ce))

# al risultato viene posto in serie un induttore Le
Lef=560e-9
Zp4(Cp,Cs,Ce,Le)=Zp3(Cp,Cs,Ce) + Zl(w(f1),Le)



# Funzioni da plottare
Zp_Zp1(t)=Gamma(Zp1(Range(t,10e-12,Cpf))/Zn)
Zp1_Zp2(t)=Gamma(Zp2(Cpf,Range(t,1e-9,Csf))/Zn)
Zp2_Zp3(t)=Gamma(Zp3(Cpf,Csf,Range(t,1e-12,Cef))/Zn)
Zp3_Zp4(t)=Gamma(Zp4(Cpf,Csf,Cef,Range(t,1e-9,Lef))/Zn)

# Punti da plottare




set grid x y

#set key on
#set key title "lines"
#set key Left reverse samplen 1 box lw 1
#set key width 1 height 1
#set key left
set key off

set samples 400
set parametric

set trange[tmin:tmax]
set xrange[-1.1:1.1]
set yrange[-1.1:1.1]

set xtics 0.20
set ytics 0.20

set title "Adattamento antenna loop"


set label 1 "Zp"  at @Pnt_Zp  @StdStyle
set label 2 "Zp1" at @Pnt_Zp1 @StdStyle
set label 3 "Zp2" at @Pnt_Zp2 @StdStyle
set label 4 "Zp3" at @Pnt_Zp3 @StdStyle
set label 5 "Zp4" at @Pnt_Zp4 @StdStyle


plot	@RefR00p,@RefR00n,@RefR05p,@RefR05n, \
	@RefR10p,@RefR10n,@RefR20p,@RefR20n, \
	@RefI00,@RefI05p,@RefI05n,@RefI10p,@RefI10n,@RefI20p,@RefI20n, \
	@RefY10p,@RefY10n,@Center, \
	real(Zp_Zp1(t)),imag(Zp_Zp1(t)) title "Path" lt 1 lw 3, \
	real(Zp1_Zp2(t)),imag(Zp1_Zp2(t)) title "Path" lt 1 lw 3, \
	real(Zp2_Zp3(t)),imag(Zp2_Zp3(t)) title "Path" lt 2 lw 3, \
	real(Zp3_Zp4(t)),imag(Zp3_Zp4(t)) title "Path" lt 2 lw 3


